You are viewing a plain text version of this content. The canonical link for it is here.
Posted to sandesha-dev@ws.apache.org by da...@apache.org on 2008/06/14 16:41:12 UTC

svn commit: r667807 - in /webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008: include/sandesha2_sender_mgr.h src/msgprocessors/app_msg_processor.c src/storage/common/sender_mgr.c src/storage/sqlite/permanent_sender_mgr.c

Author: damitha
Date: Sat Jun 14 07:41:12 2008
New Revision: 667807

URL: http://svn.apache.org/viewvc?rev=667807&view=rev
Log:
In RM 1.0 replay mode don't use sandesha2 sender threads.

Modified:
    webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/include/sandesha2_sender_mgr.h
    webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/msgprocessors/app_msg_processor.c
    webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/storage/common/sender_mgr.c
    webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/storage/sqlite/permanent_sender_mgr.c

Modified: webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/include/sandesha2_sender_mgr.h
URL: http://svn.apache.org/viewvc/webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/include/sandesha2_sender_mgr.h?rev=667807&r1=667806&r2=667807&view=diff
==============================================================================
--- webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/include/sandesha2_sender_mgr.h (original)
+++ webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/include/sandesha2_sender_mgr.h Sat Jun 14 07:41:12 2008
@@ -97,7 +97,7 @@
                 sandesha2_sender_bean_t *bean);
 
     sandesha2_sender_bean_t *(AXIS2_CALL *
-            get_next_application_msg_to_send)(
+            get_application_msg_to_send)(
                 sandesha2_sender_mgr_t *sender,
                 const axutil_env_t *env,
                 const axis2_char_t *seq_id,
@@ -168,7 +168,7 @@
     sandesha2_sender_bean_t *bean);
 
 sandesha2_sender_bean_t *AXIS2_CALL
-sandesha2_sender_mgr_get_next_application_msg_to_send(
+sandesha2_sender_mgr_get_application_msg_to_send(
     sandesha2_sender_mgr_t *sender,
     const axutil_env_t *env,
     const axis2_char_t *seq_id,

Modified: webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/msgprocessors/app_msg_processor.c
URL: http://svn.apache.org/viewvc/webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/msgprocessors/app_msg_processor.c?rev=667807&r1=667806&r2=667807&view=diff
==============================================================================
--- webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/storage/common/sender_mgr.c (original)
+++ webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/storage/common/sender_mgr.c Sat Jun 14 07:41:12 2008
@@ -96,13 +96,13 @@
 }
 
 sandesha2_sender_bean_t *AXIS2_CALL
-sandesha2_sender_mgr_get_next_application_msg_to_send(
+sandesha2_sender_mgr_get_application_msg_to_send(
     sandesha2_sender_mgr_t *sender,
     const axutil_env_t *env,
     const axis2_char_t *seq_id,
     const axis2_char_t *msg_id)
 {
-    return sender->ops.get_next_application_msg_to_send(sender, env, seq_id, msg_id);
+    return sender->ops.get_application_msg_to_send(sender, env, seq_id, msg_id);
 }
 
 sandesha2_sender_bean_t *AXIS2_CALL

Modified: webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/storage/sqlite/permanent_sender_mgr.c
URL: http://svn.apache.org/viewvc/webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/storage/sqlite/permanent_sender_mgr.c?rev=667807&r1=667806&r2=667807&view=diff
==============================================================================
--- webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/storage/sqlite/permanent_sender_mgr.c (original)
+++ webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/storage/sqlite/permanent_sender_mgr.c Sat Jun 14 07:41:12 2008
@@ -203,7 +203,7 @@
     sandesha2_sender_bean_t *bean);
 
 sandesha2_sender_bean_t *AXIS2_CALL
-sandesha2_permanent_sender_mgr_get_next_application_msg_to_send(
+sandesha2_permanent_sender_mgr_get_application_msg_to_send(
     sandesha2_sender_mgr_t *sender_mgr,
     const axutil_env_t *env,
     const axis2_char_t *seq_id,
@@ -225,7 +225,7 @@
     sandesha2_permanent_sender_mgr_find_by_internal_seq_id,
     sandesha2_permanent_sender_mgr_find_by_sender_bean,
     sandesha2_permanent_sender_mgr_find_unique,
-    sandesha2_permanent_sender_mgr_get_next_application_msg_to_send,
+    sandesha2_permanent_sender_mgr_get_application_msg_to_send,
     sandesha2_permanent_sender_mgr_get_next_msg_to_send,
 };
 
@@ -583,7 +583,7 @@
 }
 
 sandesha2_sender_bean_t *AXIS2_CALL
-sandesha2_permanent_sender_mgr_get_next_application_msg_to_send(
+sandesha2_permanent_sender_mgr_get_application_msg_to_send(
     sandesha2_sender_mgr_t *sender_mgr,
     const axutil_env_t *env,
     const axis2_char_t *seq_id,



---------------------------------------------------------------------
To unsubscribe, e-mail: sandesha-dev-unsubscribe@ws.apache.org
For additional commands, e-mail: sandesha-dev-help@ws.apache.org
--- webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/msgprocessors/app_msg_processor.c (original)
+++ webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/msgprocessors/app_msg_processor.c Sat Jun 14 07:41:12 2008
@@ -2574,7 +2574,7 @@
         axis2_transport_sender_t *transport_sender = NULL;
         sandesha2_sender_bean_t *sender_bean = NULL;
 
-        sender_bean = sandesha2_sender_mgr_get_next_application_msg_to_send(sender_mgr, env, 
+        sender_bean = sandesha2_sender_mgr_get_application_msg_to_send(sender_mgr, env, 
                 internal_sequence_id, msg_id);
         if(!sender_bean)
         {
@@ -2633,7 +2633,7 @@
                     }
                 }
                 
-                sender_bean = sandesha2_sender_mgr_get_next_application_msg_to_send(sender_mgr, env, 
+                sender_bean = sandesha2_sender_mgr_get_application_msg_to_send(sender_mgr, env, 
                     internal_sequence_id, msg_id);
                 if(!sender_bean)
                 {
@@ -2680,7 +2680,7 @@
     }
 
     /* If not (single channel) spawn a thread and see whether acknowledgment has arrived through the 
      * sandesha2_sender_mgr_get_next_application_msg_to_send() function. If it has arrived exit from
      * the thread.*/
     sandesha2_app_msg_processor_start_application_msg_resender(env, conf_ctx, internal_sequence_id, 
             msg_id, is_svr_side, sleep_time);
@@ -2690,6 +2690,7 @@
     return status;
 }
 
+/* This function will be called in the duplex mode only from within the application message sender thread. */
 static axis2_status_t
 sandesha2_app_msg_processor_resend(
     const axutil_env_t *env,
@@ -3155,6 +3156,7 @@
     axutil_env_t *env = NULL;
     sandesha2_storage_mgr_t *storage_mgr = NULL;
     sandesha2_seq_property_mgr_t *seq_prop_mgr = NULL;
+    sandesha2_create_seq_mgr_t *create_seq_mgr = NULL;
     sandesha2_sender_mgr_t *sender_mgr = NULL;
     int sleep_time = 0;
     axis2_char_t *dbname = NULL;
@@ -3178,13 +3180,13 @@
     dbname = sandesha2_util_get_dbname(env, conf_ctx);
     storage_mgr = sandesha2_utils_get_storage_mgr(env, dbname);
     seq_prop_mgr = sandesha2_permanent_seq_property_mgr_create(env, dbname);
+    create_seq_mgr = sandesha2_permanent_create_seq_mgr_create(env, dbname);
     sender_mgr = sandesha2_permanent_sender_mgr_create(env, dbname);
 
-
     while(AXIS2_TRUE)
     {
         AXIS2_SLEEP(sleep_time);
-        sender_bean = sandesha2_sender_mgr_get_next_application_msg_to_send(sender_mgr, env, 
+        sender_bean = sandesha2_sender_mgr_get_application_msg_to_send(sender_mgr, env, 
                 internal_sequence_id, msg_id);
         if(!sender_bean)
         {
@@ -3195,7 +3197,7 @@
         }
 
         status = sandesha2_app_msg_processor_resend(env, conf_ctx, msg_id, is_server_side,
-                internal_sequence_id, storage_mgr, seq_prop_mgr, NULL, 
+                internal_sequence_id, storage_mgr, seq_prop_mgr, create_seq_mgr, 
                 sender_mgr);
 
         if(AXIS2_SUCCESS != status)
@@ -2680,7 +2680,7 @@
 
     /* If not (single channel) spawn a thread and see whether acknowledgment has arrived through the 
-     * sandesha2_sender_mgr_get_next_application_msg_to_send() function. If it has arrived exit from
+     * sandesha2_sender_mgr_get_application_msg_to_send() function. If it has arrived exit from
      * the thread.*/
     sandesha2_app_msg_processor_start_application_msg_resender(env, conf_ctx, internal_sequence_id, 

Modified: webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/storage/common/sender_mgr.c
URL: http://svn.apache.org/viewvc/webservices/sandesha/tags/sandesha2/c/worker_thread_removed-23may2008/src/storage/common/sender_mgr.c?rev=667807&r1=667806&r2=667807&view=diff
==============================================================================